# LSDS Object Oriented Programming Review Assignment

Inside the `football` directory, you will find several files, including a blank `__init__.py`. Don't worry about that one right now. These files together can model several aspects of a football season including a player's statisctics, an individual football game, and a season.

As is, these modules are fully functional (well, they run without errors). You can generate a season report by running `season.py`, and you can run the tests using `football_test.py`.

That being said...

Each file (`game.py`, `players.py`, `season.py`, `possible_values.py`, and `football_test.py`) contains at least one `TODO` inside a comment. That is where you can add things and try them out to see if you're understanding how this is all done.

It makes the most sense to begin with `players.py` and `game.py` because they explain the class foundations for the rest of the files (`game.py` more so--since it is used in `season.py`).

To run anything here or in your own, edited version, clone the repo and navigate to the `football` directory in your terminal.
If you would like to run the tests or generate a season report, run `python filename.py` or `python3 filename.py` depending on your configuration with the appropriate choice of `football_test.py` or `season.py`.
If you would like to interactively create instances of the `Player`, `Quarterback`, `Game`, or your own, added, classes and run different methods on them, run `python` or `python3` in terminal and `import` the appropriate module (file name without the `.py`) on the python shell (when you see `>>>`, for example).


_Originally created by Joanne Jordan for Lambda School's Data Science program_
https://github.com/jojordan3/LSDS-OOP-assignment